@@ -202,7 +202,7 @@ sub channel_title_from_id {
 
 =head1 AUTHOR
 
-Trizen, C<< <trizenx at gmail.com> >>
+Trizen, C<< <echo dHJpemVuQHByb3Rvbm1haWwuY29tCg== | base64 -d> >>
 
 
 =head1 SUPPORT
